# Building Documentation

To make the html documentation, install the prerequisites

    $ pip install sphinx
    $ pip install mock

and build by running

    $ sphinx-build -b html docs/source docs/build
